%% EXAMPLE2: Compute logarithm of a nonnormal matrix

close all
clear all

%% setup A and v, compute exact solution for comparison
N = 500;   % problem size
d = 0.2;   % distance of evs to neg. real axis
j = 1;
while j<=N, 
    ee = 2*rand + 2i*rand - 1 - 1i;
    if abs(ee) <= 1 && ~(abs(imag(ee))<d && real(ee)<0) && ~(abs(ee)<d),
        e(j,1) = ee;
        j = j + 1;
    end;
end;
V = randn(N,N);
A = V\(diag(e)*V);
v = randn(N,1);
exact = V\(log(e).*(V*v));
tol = norm(exact)*1e-8;
maxit = 50;

%% run the method
tic
[f,xi,err] = logmv(A,v,tol,maxit,[],exact);
toc

%% plot results
subplot(1,2,1);
plot(e+1i*eps,'bo'); 
hold on; 
plot(xi+1i*eps,'r*');
legend('eigenvalues of A','selected poles');
axis([-2,2,-2,2]);
subplot(1,2,2);
semilogy(err,'k+-'); 
xlabel('iteration number');
ylabel('absolute error');
grid on

